@@ -8,7 +8,7 @@
 import os
 
 
-NL = os.linesep
+NL = '\n'
 SEPARATOR = "####################################################################################################"
 
 
@@ -43,7 +43,7 @@ def scalar_cython_conversion(scalar, flavour):
     if scalar_type in ["cl_double2", "double2"]:
         return "<cl_double2>cl_double2(x=" + scalar + ".real,y=" + scalar + ".imag)"
     if scalar_type in ["cl_half", "half"]:
-        return "<cl_half>" + scalar
+        return "<cl_half>val_to_half(" + scalar + ")"
     raise RuntimeError("Could not convert flavour '%s:%s'" % (flavour.precision_name, scalar_type))
 
 
@@ -82,8 +82,18 @@ def generate_pyx(routine):
         result += NL
 
         # Data types and checks
-        result += indent + "dtype = check_dtype([" + ", ".join(buffers) + "], "
+        int_buff = []
+        other_buff = []
+        for buf in buffers:
+            if buf in routine.index_buffers():
+                int_buff.append(buf)
+            else:
+                other_buff.append(buf)
+        result += indent + "dtype = check_dtype([" + ", ".join(other_buff) + "], "
         result += "[" + ", ".join(['"%s"' % d for d in np_dtypes]) + "])" + NL
+        if int_buff:
+            result += indent + "check_dtype([" + ", ".join(int_buff) + "], "
+            result += "[" + ", ".join(['"uint16", "uint32", "uint64"']) + "])" + NL
         for buf in buffers:
             if buf in routine.buffers_vector():
                 result += indent + "check_vector("
