@@ -365,6 +365,14 @@ class Device {
     return false;
   }
 
+  // Returns the Qualcomm Adreno GPU version (i.e. a650, a730, a740, etc.)
+  std::string AdrenoVersion() const {
+    if (IsQualcomm()) {
+      return GetInfoString(CL_DEVICE_OPENCL_C_VERSION);
+    }
+    else { return std::string{""}; }
+  }
+
   // Retrieves the above extra information (if present)
   std::string GetExtraInfo() const {
     if (HasExtension("cl_amd_device_attribute_query")) { return AMDBoardName(); }
@@ -479,7 +487,8 @@ class Program {
 
   // Clean-up
   ~Program() {
-    #ifndef _MSC_VER // causes an access violation under Windows when the driver is already unloaded
+    // Causes an access violation under Windows or Android when the driver is already unloaded
+    #if !defined(__ANDROID__) && !defined(_MSC_VER)
       if (program_) { CheckErrorDtor(clReleaseProgram(program_)); }
     #endif
   }
